@@ -2,22 +2,23 @@
 
 from __future__ import unicode_literals
 
-import uuid
-
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models, transaction
-from django.utils.encoding import force_text
 from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
+
 from six import python_2_unicode_compatible
 
 from . import classproperty
 from .cache import clear_cache, query_cache, update_cache
+from .compat import force_str
 from .debug import debug_performance
 from .memory import clear_refs, update_refs
 from .signals import connect_signals, no_signals
 from .utils import join_pks, split_pks
 
+import uuid
+
 
 @python_2_unicode_compatible
 class TreeNodeModel(models.Model):
@@ -95,7 +96,7 @@ class TreeNodeModel(models.Model):
         validators=[MinValueValidator(0), MaxValueValidator(9999)],
         verbose_name=_('Priority'), )
 
-    tn_order = models.PositiveSmallIntegerField(
+    tn_order = models.PositiveIntegerField(
         default=0, editable=False,
         verbose_name=_('Order'), )
 
@@ -109,8 +110,11 @@ class TreeNodeModel(models.Model):
 
     # Public methods
 
-    def delete(self, using=None, keep_parents=False):
+    def delete(self, using=None, keep_parents=False, cascade=True):
         with no_signals():
+            if not cascade:
+                children_qs = self.get_children_queryset()
+                children_qs.update(tn_parent=None)
             self.__class__.objects.filter(pk=self.pk).delete()
         self.update_tree()
 
@@ -197,20 +201,25 @@ class TreeNodeModel(models.Model):
 
     def get_display(self, indent=True, mark='— '):
         indentation = (mark * self.tn_ancestors_count) if indent else ''
-        indentation = force_text(indentation)
+        indentation = force_str(indentation)
         text = self.get_display_text()
+        text = force_str(text)
         return indentation + text
 
     def get_display_text(self):
         """
         Gets the text that will be indented in `get_display` method.
-        Returns the `treenode_display_field` value by default.
+        Returns the `treenode_display_field` value if specified,
+        otherwise falls back on the model's pk.
         Override this method to return another field or a computed value. #27
         """
-        field_name = getattr(self, 'treenode_display_field', 'pk')
-        text = getattr(self, field_name)
-        text = force_text(text)
-        return text
+        text = ''
+        if hasattr(self, 'treenode_display_field') and self.treenode_display_field is not None:
+            field_name = getattr(self, 'treenode_display_field')
+            text = getattr(self, field_name, '')
+        if not text and self.pk:
+            text = self.pk
+        return force_str(text)
 
     def get_first_child(self, cache=True):
         return self.get_children(cache=cache)[0] \
@@ -619,7 +628,7 @@ class TreeNodeModel(models.Model):
 
         return objs_tree
 
-    #  Public properties
+    # Public properties
     # All properties map a get_{{property}}() method.
 
     @property
